@@ -3,6 +3,6 @@ __all__ = [
     'dae_read',
     'obj_write',
     'obj_read',
-    'scw_write',
-    'scw_read'
+    'gltf',
+    'scw'
 ]
